==> aptechka-0.43.1.tgz: package/lib/source/index.js <==
var W = (n) => {
  throw TypeError(n);
};
var G = (n, r, e) => r.has(n) || W("Cannot " + e);
var t = (n, r, e) => (G(n, r, "read from private field"), e ? e.call(n) : r.get(n)), i = (n, r, e) => r.has(n) ? W("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(n) : r.set(n, e), s = (n, r, e, o) => (G(n, r, "write to private field"), o ? o.call(n, e) : r.set(n, e), e), U = (n, r, e) => (G(n, r, "access private method"), e);
import { ClassLinkedStatus as Q } from "../class-linked-status/index.js";
import { i as X } from "../browser-0zX67oeU.js";
import { d as D } from "../events-CsVF98U6.js";
import { k as Y } from "../string-f0Dnk0L1.js";
import { loading as K } from "../loading/index.js";
import { RESIZE_ORDER as tt } from "../order/index.js";
import { windowResizer as Z } from "../window-resizer/index.js";
import { S as et } from "../Store-Cm3LPXlx.js";
var C, E, O, L, u, f, k;
class st {
  constructor(r) {
    i(this, C);
    i(this, E);
    i(this, O);
    i(this, L);
    i(this, u);
    i(this, f);
    i(this, k);
    s(this, C, r);
    let e = r.split(".");
    const o = /\b\d{1,2}x\b/g, d = e.find((g) => g.match(o) && parseInt(g));
    s(this, O, d ? parseInt(d) : 1), d && (e = e.slice(0, -1)), s(this, E, e.length > 1 ? e.slice(0, -1).join(".") : e.join("."));
    const l = /\d+max/g, x = /\d+min/g, B = /\d+mar/g, P = /\d+mir/g, _ = e.find((g) => g.match(l)), h = e.find((g) => g.match(x)), b = e.find((g) => g.match(B)), N = e.find((g) => g.match(P));
    b ? (s(this, u, parseInt(b)), s(this, f, "max"), s(this, L, `(max-aspect-ratio: ${t(this, u)})`)) : N ? (s(this, u, parseInt(N)), s(this, f, "max"), s(this, L, `(min-aspect-ratio: ${t(this, u)})`)) : _ ? (s(this, u, parseInt(_)), s(this, f, "max"), s(this, L, `(max-width: ${t(this, u)}px)`)) : h ? (s(this, u, parseInt(h)), s(this, L, `(min-width: ${t(this, u)}px)`), s(this, f, "min")) : (s(this, u, 0), s(this, L, `(min-width: ${t(this, u)}px)`), s(this, f, "min")), s(this, E, t(this, E).replace(
      `.${t(this, u)}${t(this, f)}`,
      ""
    )), s(this, k, e[e.length - 1] === t(this, E) ? "" : "." + e[e.length - 1]), s(this, k, t(this, k).replace(
      `.${t(this, u)}${t(this, f)}`,
      ""
    ));
  }
  get url() {
    return t(this, C);
  }
  get name() {
    return t(this, E);
  }
  get density() {
    return t(this, O);
  }
  get query() {
    return t(this, L);
  }
  get extension() {
    return t(this, k);
  }
  get queryType() {
    return t(this, f);
  }
  get queryValue() {
    return t(this, u);
  }
}
C = new WeakMap(), E = new WeakMap(), O = new WeakMap(), L = new WeakMap(), u = new WeakMap(), f = new WeakMap(), k = new WeakMap();
let it = 0;
var m, a, y, w, p, V, A, c, M, R, S, z, $, F, H, v, j;
class ft extends HTMLElement {
  constructor(e) {
    super();
    i(this, $);
    i(this, m, null);
    i(this, a, null);
    i(this, y, !1);
    i(this, w, !1);
    i(this, p, !1);
    i(this, V, "");
    i(this, A, "");
    i(this, c, new Q(this, {
      loading: !1,
      loaded: !1,
      error: !1,
      clear: !1
    }));
    i(this, M, null);
    i(this, R);
    i(this, S, null);
    i(this, z);
    i(this, H, (e) => {
      const o = e[0];
      t(this, p) && (!t(this, w) || this.hasAttribute("reload-source")) && o.isIntersecting && this.triggerLazyLoad(), o.isIntersecting ? D(this, "sourceCapture", { custom: !0 }) : (this.hasAttribute("reload-source") && (U(this, $, F).call(this, void 0), s(this, w, !1)), D(this, "sourceRelease", { custom: !0 }));
    });
    i(this, v, () => {
      t(this, c).set("loaded", !0), t(this, c).set("error", !1), t(this, c).set("loading", !1), !t(this, p) && !t(this, y) && K.complete(t(this, A)), D(this, "sourceLoaded", { custom: !0 });
      const e = getComputedStyle(this).getPropertyValue("--clear-duration");
      e ? s(this, R, setTimeout(() => {
        t(this, c).set("clear", !0);
      }, parseFloat(e) * 1e3)) : t(this, c).set("clear", !0), s(this, y, !0);
    });
    i(this, j, (e) => {
      t(this, c).set("loaded", !1), t(this, c).set("error", !0), t(this, c).set("loading", !1), !t(this, p) && !t(this, y) && K.error(t(this, A)), D(this, "sourceError", { custom: !0 }), s(this, y, !0);
    });
    s(this, z, e == null ? void 0 : e.sourceSetOptions), X && window.IntersectionObserver && s(this, M, new IntersectionObserver(
      t(this, H)
    ));
  }
  get consumerElement() {
    return t(this, a);
  }
  get sourceManager() {
    return t(this, m);
  }
  get status() {
    return t(this, c);
  }
  get isLazy() {
    return t(this, p);
  }
  get currentURL() {
    return t(this, S);
  }
  get isFirstLoadHappened() {
    return t(this, y);
  }
  triggerLazyLoad() {
    !t(this, w) && t(this, m).current && t(this, m).current !== t(this, m).previous && (s(this, w, !0), U(this, $, F).call(this, t(this, m).current));
  }
  connectedCallback() {
    s(this, V, `source-consumer-${++it}`);
    const e = this.getAttribute("srcset") || "", o = this.hasAttribute("notify") ? this.closest(this.getAttribute("notify")) : null;
    o && t(this, c).addElement(o), s(this, a, this.createConsumer()), t(this, a).style.cssText = `
        display: block;
        width: 100%;
        height: 100%;
      `, t(this, a).classList.add("source-consumer"), Array.from(this.attributes).forEach((d) => {
      if (d.name !== "srcset") {
        const l = d.nodeValue || "", x = Y(d.name);
        x in t(this, a) && (t(this, a)[x] = l || !0);
      }
    }), this.appendChild(t(this, a)), s(this, m, new rt({
      srcset: e,
      sourceSetOptions: t(this, z)
    })), s(this, p, this.hasAttribute("lazy")), t(this, m).subscribe((d) => {
      (!t(this, p) || t(this, p) && t(this, w)) && U(this, $, F).call(this, d.current);
    }), t(this, m).connect(), t(this, M).observe(this);
  }
  disconnectedCallback() {
    var e;
    clearTimeout(t(this, R)), t(this, M).disconnect(), (e = t(this, m)) == null || e.close(), t(this, a) && (t(this, a).onloadeddata = null, t(this, a).onload = null, t(this, a).onerror = null, t(this, a).remove()), s(this, y, !1), s(this, w, !1), t(this, c).reset();
  }
}
m = new WeakMap(), a = new WeakMap(), y = new WeakMap(), w = new WeakMap(), p = new WeakMap(), V = new WeakMap(), A = new WeakMap(), c = new WeakMap(), M = new WeakMap(), R = new WeakMap(), S = new WeakMap(), z = new WeakMap(), $ = new WeakSet(), F = function(e) {
  if (clearTimeout(t(this, R)), t(this, a).onloadeddata = null, t(this, a).onload = null, t(this, a).onerror = null, t(this, c).set("loaded", !1), t(this, c).set("error", !1), t(this, c).set("loading", !1), t(this, c).set("clear", !1), e) {
    s(this, A, `${t(this, V)}-${e.url}`);
    const o = this.hasAttribute("keep-source-parameters");
    t(this, c).set("loading", !0), s(this, S, o ? e.url : e.name + e.extension), this.consumeSource(t(this, S)), !t(this, p) && !t(this, y) && K.add(t(this, A)), t(this, a).onloadeddata = () => {
      t(this, v).call(this);
    }, t(this, a).onload = () => {
      t(this, v).call(this);
    }, t(this, a).onerror = () => {
      t(this, j).call(this, t(this, S));
    };
  } else
    s(this, S, null), this.consumeSource(null);
}, H = new WeakMap(), v = new WeakMap(), j = new WeakMap();
var q;
class J {
  constructor(r, e) {
    i(this, q);
    s(this, q, /* @__PURE__ */ new Map());
    const o = (e == null ? void 0 : e.mediaBuckets) !== !1, d = typeof r == "string" ? o ? r.trim().split(",").map((h) => h.trim()).filter((h) => !!h) : [r] : r, l = [];
    d.forEach((h) => {
      const b = new st(h);
      l.push([b.query, b]);
    });
    const x = l.filter((h) => h[1].queryType.includes("max")).sort((h, b) => b[1].queryValue - h[1].queryValue), B = l.filter((h) => h[1].queryType.includes("min") && h[1].queryValue !== 0).sort((h, b) => h[1].queryValue - b[1].queryValue), P = l.filter((h) => h[0] === "(min-width: 0px)");
    (P ? [...P, ...x, ...B] : [...x, ...B]).forEach((h) => {
      t(this, q).has(h[0]) || t(this, q).set(h[0], []), t(this, q).get(h[0]).push(h[1]);
    });
  }
  get mediaBuckets() {
    return t(this, q);
  }
}
q = new WeakMap();
var T, I;
class rt extends et {
  constructor(e) {
    super(void 0);
    i(this, T);
    i(this, I, () => {
      let e;
      t(this, T).mediaBuckets.forEach((l, x) => {
        matchMedia(x).matches && (e = l);
      });
      let o, d = 0;
      e == null || e.forEach((l) => {
        l.density > d && l.density <= Math.max(devicePixelRatio, 1) && (d = l.density, o = l);
      }), e != null && e.length && !o && (o = e[0]), this.current = o;
    });
    s(this, T, new J(e.srcset, e.sourceSetOptions));
  }
  updateSource(e) {
    s(this, T, new J(e.srcset, e.sourceSetOptions)), t(this, I).call(this);
  }
  close() {
    super.close(), this.disconnect();
  }
  connect() {
    Z.subscribe(t(this, I), tt.SOURCE_MANAGER), t(this, I).call(this);
  }
  disconnect() {
    Z.unsubscribe(t(this, I));
  }
}
T = new WeakMap(), I = new WeakMap();
export {
  st as Source,
  ft as SourceElement,
  rt as SourceManager,
  J as SourceSet
};

==> aptechka-0.47.11.tgz: package/lib/source/index.js <==
var W = (n) => {
  throw TypeError(n);
};
var G = (n, r, e) => r.has(n) || W("Cannot " + e);
var t = (n, r, e) => (G(n, r, "read from private field"), e ? e.call(n) : r.get(n)), i = (n, r, e) => r.has(n) ? W("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(n) : r.set(n, e), s = (n, r, e, o) => (G(n, r, "write to private field"), o ? o.call(n, e) : r.set(n, e), e), U = (n, r, e) => (G(n, r, "access private method"), e);
import { ClassLinkedStatus as Q } from "../class-linked-status/index.js";
import { i as X } from "../index-euf5anj6.js";
import { d as D } from "../events-CsVF98U6.js";
import { k as Y } from "../string-f0Dnk0L1.js";
import { loading as K } from "../loading/index.js";
import { RESIZE_ORDER as tt } from "../order/index.js";
import { windowResizer as Z } from "../window-resizer/index.js";
import { S as et } from "../Store-D2xCXENW.js";
var C, E, O, L, u, f, k;
class st {
  constructor(r) {
    i(this, C);
    i(this, E);
    i(this, O);
    i(this, L);
    i(this, u);
    i(this, f);
    i(this, k);
    s(this, C, r);
    let e = r.split(".");
    const o = /\b\d{1,2}x\b/g, d = e.find((g) => g.match(o) && parseInt(g));
    s(this, O, d ? parseInt(d) : 1), d && (e = e.slice(0, -1)), s(this, E, e.length > 1 ? e.slice(0, -1).join(".") : e.join("."));
    const l = /\d+max/g, x = /\d+min/g, B = /\d+mar/g, P = /\d+mir/g, _ = e.find((g) => g.match(l)), h = e.find((g) => g.match(x)), b = e.find((g) => g.match(B)), N = e.find((g) => g.match(P));
    b ? (s(this, u, parseInt(b)), s(this, f, "max"), s(this, L, `(max-aspect-ratio: ${t(this, u)})`)) : N ? (s(this, u, parseInt(N)), s(this, f, "max"), s(this, L, `(min-aspect-ratio: ${t(this, u)})`)) : _ ? (s(this, u, parseInt(_)), s(this, f, "max"), s(this, L, `(max-width: ${t(this, u)}px)`)) : h ? (s(this, u, parseInt(h)), s(this, L, `(min-width: ${t(this, u)}px)`), s(this, f, "min")) : (s(this, u, 0), s(this, L, `(min-width: ${t(this, u)}px)`), s(this, f, "min")), s(this, E, t(this, E).replace(
      `.${t(this, u)}${t(this, f)}`,
      ""
    )), s(this, k, e[e.length - 1] === t(this, E) ? "" : "." + e[e.length - 1]), s(this, k, t(this, k).replace(
      `.${t(this, u)}${t(this, f)}`,
      ""
    ));
  }
  get url() {
    return t(this, C);
  }
  get name() {
    return t(this, E);
  }
  get density() {
    return t(this, O);
  }
  get query() {
    return t(this, L);
  }
  get extension() {
    return t(this, k);
  }
  get queryType() {
    return t(this, f);
  }
  get queryValue() {
    return t(this, u);
  }
}
C = new WeakMap(), E = new WeakMap(), O = new WeakMap(), L = new WeakMap(), u = new WeakMap(), f = new WeakMap(), k = new WeakMap();
let it = 0;
var m, a, y, w, p, V, A, c, M, R, S, z, $, F, H, v, j;
class ft extends HTMLElement {
  constructor(e) {
    super();
    i(this, $);
    i(this, m, null);
    i(this, a, null);
    i(this, y, !1);
    i(this, w, !1);
    i(this, p, !1);
    i(this, V, "");
    i(this, A, "");
    i(this, c, new Q(this, {
      loading: !1,
      loaded: !1,
      error: !1,
      clear: !1
    }));
    i(this, M, null);
    i(this, R);
    i(this, S, null);
    i(this, z);
    i(this, H, (e) => {
      const o = e[0];
      t(this, p) && (!t(this, w) || this.hasAttribute("reload-source")) && o.isIntersecting && this.triggerLazyLoad(), o.isIntersecting ? D(this, "sourceCapture", { custom: !0 }) : (this.hasAttribute("reload-source") && (U(this, $, F).call(this, void 0), s(this, w, !1)), D(this, "sourceRelease", { custom: !0 }));
    });
    i(this, v, () => {
      t(this, c).set("loaded", !0), t(this, c).set("error", !1), t(this, c).set("loading", !1), !t(this, p) && !t(this, y) && K.complete(t(this, A)), D(this, "sourceLoaded", { custom: !0 });
      const e = getComputedStyle(this).getPropertyValue("--clear-duration");
      e ? s(this, R, setTimeout(() => {
        t(this, c).set("clear", !0);
      }, parseFloat(e) * 1e3)) : t(this, c).set("clear", !0), s(this, y, !0);
    });
    i(this, j, (e) => {
      t(this, c).set("loaded", !1), t(this, c).set("error", !0), t(this, c).set("loading", !1), !t(this, p) && !t(this, y) && K.error(t(this, A)), D(this, "sourceError", { custom: !0 }), s(this, y, !0);
    });
    s(this, z, e == null ? void 0 : e.sourceSetOptions), X && window.IntersectionObserver && s(this, M, new IntersectionObserver(
      t(this, H)
    ));
  }
  get consumerElement() {
    return t(this, a);
  }
  get sourceManager() {
    return t(this, m);
  }
  get status() {
    return t(this, c);
  }
  get isLazy() {
    return t(this, p);
  }
  get currentURL() {
    return t(this, S);
  }
  get isFirstLoadHappened() {
    return t(this, y);
  }
  triggerLazyLoad() {
    !t(this, w) && t(this, m).current && t(this, m).current !== t(this, m).previous && (s(this, w, !0), U(this, $, F).call(this, t(this, m).current));
  }
  connectedCallback() {
    s(this, V, `source-consumer-${++it}`);
    const e = this.getAttribute("srcset") || "", o = this.hasAttribute("notify") ? this.closest(this.getAttribute("notify")) : null;
    o && t(this, c).addElement(o), s(this, a, this.createConsumer()), t(this, a).style.cssText = `
        display: block;
        width: 100%;
        height: 100%;
      `, t(this, a).classList.add("source-consumer"), Array.from(this.attributes).forEach((d) => {
      if (d.name !== "srcset") {
        const l = d.nodeValue || "", x = Y(d.name);
        x in t(this, a) && (t(this, a)[x] = l || !0);
      }
    }), this.appendChild(t(this, a)), s(this, m, new rt({
      srcset: e,
      sourceSetOptions: t(this, z)
    })), s(this, p, this.hasAttribute("lazy")), t(this, m).subscribe((d) => {
      (!t(this, p) || t(this, p) && t(this, w)) && U(this, $, F).call(this, d.current);
    }), t(this, m).connect(), t(this, M).observe(this);
  }
  disconnectedCallback() {
    var e;
    clearTimeout(t(this, R)), t(this, M).disconnect(), (e = t(this, m)) == null || e.close(), t(this, a) && (t(this, a).onloadeddata = null, t(this, a).onload = null, t(this, a).onerror = null, t(this, a).remove()), s(this, y, !1), s(this, w, !1), t(this, c).reset();
  }
}
m = new WeakMap(), a = new WeakMap(), y = new WeakMap(), w = new WeakMap(), p = new WeakMap(), V = new WeakMap(), A = new WeakMap(), c = new WeakMap(), M = new WeakMap(), R = new WeakMap(), S = new WeakMap(), z = new WeakMap(), $ = new WeakSet(), F = function(e) {
  if (clearTimeout(t(this, R)), t(this, a).onloadeddata = null, t(this, a).onload = null, t(this, a).onerror = null, t(this, c).set("loaded", !1), t(this, c).set("error", !1), t(this, c).set("loading", !1), t(this, c).set("clear", !1), e) {
    s(this, A, `${t(this, V)}-${e.url}`);
    const o = this.hasAttribute("keep-source-parameters");
    t(this, c).set("loading", !0), s(this, S, o ? e.url : e.name + e.extension), this.consumeSource(t(this, S)), !t(this, p) && !t(this, y) && K.add(t(this, A)), t(this, a).onloadeddata = () => {
      t(this, v).call(this);
    }, t(this, a).onload = () => {
      t(this, v).call(this);
    }, t(this, a).onerror = () => {
      t(this, j).call(this, t(this, S));
    };
  } else
    s(this, S, null), this.consumeSource(null);
}, H = new WeakMap(), v = new WeakMap(), j = new WeakMap();
var q;
class J {
  constructor(r, e) {
    i(this, q);
    s(this, q, /* @__PURE__ */ new Map());
    const o = (e == null ? void 0 : e.mediaBuckets) !== !1, d = typeof r == "string" ? o ? r.trim().split(",").map((h) => h.trim()).filter((h) => !!h) : [r] : r, l = [];
    d.forEach((h) => {
      const b = new st(h);
      l.push([b.query, b]);
    });
    const x = l.filter((h) => h[1].queryType.includes("max")).sort((h, b) => b[1].queryValue - h[1].queryValue), B = l.filter((h) => h[1].queryType.includes("min") && h[1].queryValue !== 0).sort((h, b) => h[1].queryValue - b[1].queryValue), P = l.filter((h) => h[0] === "(min-width: 0px)");
    (P ? [...P, ...x, ...B] : [...x, ...B]).forEach((h) => {
      t(this, q).has(h[0]) || t(this, q).set(h[0], []), t(this, q).get(h[0]).push(h[1]);
    });
  }
  get mediaBuckets() {
    return t(this, q);
  }
}
q = new WeakMap();
var T, I;
class rt extends et {
  constructor(e) {
    super(void 0);
    i(this, T);
    i(this, I, () => {
      let e;
      t(this, T).mediaBuckets.forEach((l, x) => {
        matchMedia(x).matches && (e = l);
      });
      let o, d = 0;
      e == null || e.forEach((l) => {
        l.density > d && l.density <= Math.max(devicePixelRatio, 1) && (d = l.density, o = l);
      }), e != null && e.length && !o && (o = e[0]), this.current = o;
    });
    s(this, T, new J(e.srcset, e.sourceSetOptions));
  }
  updateSource(e) {
    s(this, T, new J(e.srcset, e.sourceSetOptions)), t(this, I).call(this);
  }
  close() {
    super.close(), this.disconnect();
  }
  connect() {
    Z.subscribe(t(this, I), tt.SOURCE_MANAGER), t(this, I).call(this);
  }
  disconnect() {
    Z.unsubscribe(t(this, I));
  }
}
T = new WeakMap(), I = new WeakMap();
export {
  st as Source,
  ft as SourceElement,
  rt as SourceManager,
  J as SourceSet
};
